==> nginx_install-0.1.4.tar.gz: nginx_install-0.1.4/nginx_install/installers/openssl.py <==
import bs4
import re
from .base import BaseInstaller

ver_re = re.compile(r".*?(\d+\.\d+\.\d+)$")


class OpenSSLInstaller(BaseInstaller):
    enabled: bool = False

    async def prepare(self, ctx):
        logger = ctx.logger
        logger.debug("%s: Preparing OpenSSL installer", self)
        client = ctx.client

        r = await client.get(
            "https://github.com/openssl/openssl/releases/latest",
            follow_redirects=True,
        )
        r.raise_for_status()

        soup = bs4.BeautifulSoup(r.content, "lxml")
        v = ''
        for h1 in soup.find_all("h1"):
            m = ver_re.match(h1.text.strip())
            if m:
                v = m.group(1)
                break
        if not v:
            raise RuntimeError(f"{self}: Failed to find latest version")

        logger.debug("%s: Latest OpenSSL release version: %s", self, v)
        fpath = ctx.build_dir / f"openssl-{v}.tar.gz"
        await ctx.download(
            "https://github.com/openssl/openssl/releases/download/"
            f"openssl-{v}/openssl-{v}.tar.gz",
            fpath,
            title="Get openssl source",
        )

        rs = await ctx.run_cmd(
            f"tar -xzf '{fpath}' -C '{ctx.build_dir}'",
        )
        rs.raise_for_returncode()

        dpath = ctx.build_dir / f"openssl-{v}"
        rs = await ctx.run_cmd(
            f"cd '{dpath}' && ./config",
        )
        rs.raise_for_returncode()

        ctx.core.configure_opts.append(f"--with-openssl=../openssl-{v}")

    async def build(self, ctx):
        ...

    async def install(self, ctx):
        ...

    async def uninstall(self, ctx):
        ...

    async def clean(self, ctx):
        ...

==> nginx_install-0.1.11.tar.gz: nginx_install-0.1.11/nginx_install/installers/openssl.py <==
import bs4
import re
from os.path import relpath
from .base import BuiltinInstaller

ver_re = re.compile(r".*?(\d+\.\d+\.\d+)$")


class OpenSSLInstaller(BuiltinInstaller):
    enabled: bool = False

    async def prepare(self, ctx):
        logger = ctx.logger
        logger.debug("%s: Preparing OpenSSL installer", self)
        client = ctx.client
        task = ctx.progress.add_task("Prepare OpenSSL", total=4)

        r = await client.get(
            "https://github.com/openssl/openssl/releases/latest",
            follow_redirects=True,
        )
        r.raise_for_status()

        ctx.progress.update(task, advance=1)

        soup = bs4.BeautifulSoup(r.content, "lxml")
        v = ''
        for h1 in soup.find_all("h1"):
            m = ver_re.match(h1.text.strip())
            if m:
                v = m.group(1)
                break
        if not v:
            raise RuntimeError(f"{self}: Failed to find latest version")

        logger.debug("%s: Latest OpenSSL release version: %s", self, v)
        fpath = ctx.build_dir / f"openssl-{v}.tar.gz"
        await ctx.download(
            "https://github.com/openssl/openssl/releases/download/"
            f"openssl-{v}/openssl-{v}.tar.gz",
            fpath,
            title="Get openssl source",
        )

        ctx.progress.update(task, advance=1)

        rs = await ctx.run_cmd(
            f"tar -xzf '{fpath}' -C '{ctx.build_dir}'",
        )
        rs.raise_for_returncode()

        ctx.progress.update(task, advance=1)

        dpath = ctx.build_dir / f"openssl-{v}"
        rs = await ctx.run_cmd(
            f"cd '{dpath}' && ./config",
        )
        rs.raise_for_returncode()

        ctx.core.configure_opts.append(
            f"--with-openssl={relpath(dpath, ctx.nginx_src_dir)}")
        ctx.progress.update(task, advance=1)

    async def build(self, ctx):
        ...

    async def install(self, ctx):
        ...

    async def uninstall(self, ctx):
        ...

    async def clean(self, ctx):
        ...
